# lazy-rpc
rpc module for python.

## features
- [ ] SSL/TLS for kafka module

## for developer
### setup
```bash
pip install pipenv
pipenv install
pipenv install --dev
docker-compose up --build
export PYTHONPATH=$(pwd)
```
